{
  lib,
  config,
  ...
}:
let
  cfg = config.krop.hm.programs.git;
in
{
  options.krop.hm.programs.git = {
    enable = lib.mkOption {
      type = lib.types.bool;
      default = true;
      example = false;
      description = "Enable my git configuration";
    };
    work-config = lib.mkOption {
      type = lib.types.bool;
      default = false;
      example = true;
      description = "Generate my job configuration";
    };
    signing = lib.mkOption {
      type = lib.types.bool;
      default = false;
      example = true;
      description = "Sign all commits";
    };
  };
  config = lib.mkIf cfg.enable {
    programs.git = {
      enable = true;
      userName = "Jakub Kropáček";
      userEmail = "kropikuba@gmail.com";
      signing = lib.mkIf cfg.signing {
        format = "openpgp";
        key = "4EC6A2C45D75FC86";
        signByDefault = true;
      };
      includes =
        if cfg.work-config then
          let
            workcfg = {
              user = {
                email = "jakub.kropacek@olc.cz";
                name = "Jakub Kropáček";

                signingkey = lib.optionalString cfg.signing "E1464E538D595102";
              };
            };
          in
          [
            {
              condition = "gitdir:~/Repositories/OLC/**";
              contents = workcfg;
            }
            {
              condition = "gitdir:~/Repositories/OLC-Hexpol/**";
              contents = workcfg;
            }
          ]
        else
          [ ];
      extraConfig = {
        init = {
          defaultBranch = "master";
        };
        push = {
          autoSetupRemote = true;
        };
        status = {
          submoduleSummary = true;
        };
        diff = {
          submodule = "log";
        };
        core = {
          autocrlf = "input";
        };
        pull = {
          rebase = true;
        };
      };
    };
  };
}
